@@ -11,7 +11,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import List
+from typing import IO, List, Union
 
 if sys.version_info >= (3, 8):
     from typing import Literal
@@ -29,6 +29,7 @@ __all__ = (
     "CertificateTypeDef",
     "ConnectionTypeDef",
     "DmsTransferSettingsTypeDef",
+    "DocDbSettingsTypeDef",
     "DynamoDbSettingsTypeDef",
     "ElasticsearchSettingsTypeDef",
     "EndpointTypeDef",
@@ -134,7 +135,7 @@ CertificateTypeDef = TypedDict(
         "CertificateIdentifier": str,
         "CertificateCreationDate": datetime,
         "CertificatePem": str,
-        "CertificateWallet": bytes,
+        "CertificateWallet": Union[bytes, IO[bytes]],
         "CertificateArn": str,
         "CertificateOwner": str,
         "ValidFromDate": datetime,
@@ -162,6 +163,22 @@ DmsTransferSettingsTypeDef = TypedDict(
     "DmsTransferSettingsTypeDef", {"ServiceAccessRoleArn": str, "BucketName": str}, total=False
 )
 
+DocDbSettingsTypeDef = TypedDict(
+    "DocDbSettingsTypeDef",
+    {
+        "Username": str,
+        "Password": str,
+        "ServerName": str,
+        "Port": int,
+        "DatabaseName": str,
+        "NestingLevel": Literal["none", "one"],
+        "ExtractDocId": bool,
+        "DocsToInvestigate": int,
+        "KmsKeyId": str,
+    },
+    total=False,
+)
+
 DynamoDbSettingsTypeDef = TypedDict("DynamoDbSettingsTypeDef", {"ServiceAccessRoleArn": str})
 
 _RequiredElasticsearchSettingsTypeDef = TypedDict(
@@ -215,6 +232,7 @@ EndpointTypeDef = TypedDict(
         "SybaseSettings": "SybaseSettingsTypeDef",
         "MicrosoftSQLServerSettings": "MicrosoftSQLServerSettingsTypeDef",
         "IBMDb2Settings": "IBMDb2SettingsTypeDef",
+        "DocDbSettings": "DocDbSettingsTypeDef",
     },
     total=False,
 )
